<?php
/*
Plugin Name: WooCommerce Free Shipping Notice (EasyToolsWP)
Description: Display a notice for free shipping in the cart when minimum or maximum amounts are met.
Version: 1.3
Author: EasyToolsWP
*/

// Hook to add a settings page under the admin menu
add_action('admin_menu', 'etwp_fsn_add_admin_menu');
add_action('admin_init', 'etwp_fsn_settings_init');

// Hook to display a custom message in the cart and checkout
add_action('woocommerce_before_cart_totals', 'etwp_fsn_free_shipping_cart_label');
add_action('woocommerce_before_checkout_form', 'etwp_fsn_free_shipping_checkout_label');

// Function to add the settings page
function etwp_fsn_add_admin_menu() { 
    add_submenu_page('', 'WooCommerce Free Shipping Notice', 'Free Shipping Notice', 'manage_options', 'easytoolswp_pro-settings', 'etwp_fsn_options_page');
}

// Function to initialize settings
function etwp_fsn_settings_init() { 
    // Default values
    $defaults = array(
        'etwp_fsn_min_amount' => 50,
        'etwp_fsn_max_amount' => 9999,
        'etwp_fsn_free_shipping_amount' => 100,
        'etwp_fsn_free_shipping_text' => __('You now have free shipping!', 'easytoolswp'),
        'etwp_fsn_buy_for_text' => __('Buy for', 'easytoolswp'),
        'etwp_fsn_more_for_text' => __('more for free delivery!', 'easytoolswp'),
    );

    // Retrieve existing settings or use defaults
    $options = get_option('etwp_fsn_settings', $defaults);

    // Register settings
    register_setting('etwp_fsnSettings', 'etwp_fsn_settings');

    // Add settings section
    add_settings_section(
        'etwp_fsn_section', 
        __('Free Shipping Notice Settings', 'easytoolswp'), 
        'etwp_fsn_settings_section_callback', 
        'etwp_fsnSettings'
    );

    // Add fields
    add_settings_field('etwp_fsn_free_shipping_amount', __('Free Shipping Threshold', 'easytoolswp'), 'etwp_fsn_free_shipping_amount_render', 'etwp_fsnSettings', 'etwp_fsn_section');    
    add_settings_field('etwp_fsn_min_amount', __('No Alert BELOW This Amount', 'easytoolswp'), 'etwp_fsn_min_amount_render', 'etwp_fsnSettings', 'etwp_fsn_section');
    add_settings_field('etwp_fsn_max_amount', __('No Alert ABOVE This Amount', 'easytoolswp'), 'etwp_fsn_max_amount_render', 'etwp_fsnSettings', 'etwp_fsn_section');
    add_settings_field('etwp_fsn_free_shipping_text', __('Free Shipping Notice Text', 'easytoolswp'), 'etwp_fsn_free_shipping_text_render', 'etwp_fsnSettings', 'etwp_fsn_section');
    add_settings_field('etwp_fsn_buy_for_text', __('Prefix Text', 'easytoolswp'), 'etwp_fsn_buy_for_text_render', 'etwp_fsnSettings', 'etwp_fsn_section');
    add_settings_field('etwp_fsn_more_for_text', __('Suffix Text', 'easytoolswp'), 'etwp_fsn_more_for_text_render', 'etwp_fsnSettings', 'etwp_fsn_section');
}

// Rendering functions for settings fields
function etwp_fsn_free_shipping_amount_render() { 
    $options = get_option('etwp_fsn_settings');
    ?>
    <input type='number' name='etwp_fsn_settings[etwp_fsn_free_shipping_amount]' value='<?php echo esc_attr($options['etwp_fsn_free_shipping_amount']); ?>' step='0.01'>
    <?php
}
function etwp_fsn_min_amount_render() { 
    $options = get_option('etwp_fsn_settings');
    ?>
    <input type='number' name='etwp_fsn_settings[etwp_fsn_min_amount]' value='<?php echo esc_attr($options['etwp_fsn_min_amount']); ?>' step='0.01'>
    <?php
}
function etwp_fsn_max_amount_render() { 
    $options = get_option('etwp_fsn_settings');
    ?>
    <input type='number' name='etwp_fsn_settings[etwp_fsn_max_amount]' value='<?php echo esc_attr($options['etwp_fsn_max_amount']); ?>' step='0.01'>
    <?php
}
function etwp_fsn_free_shipping_text_render() {
    $options = get_option('etwp_fsn_settings');
    ?>
    <input type='text' name='etwp_fsn_settings[etwp_fsn_free_shipping_text]' value='<?php echo esc_attr($options['etwp_fsn_free_shipping_text']); ?>'>
    <?php
}
function etwp_fsn_buy_for_text_render() {
    $options = get_option('etwp_fsn_settings');
    ?>
    <input type='text' name='etwp_fsn_settings[etwp_fsn_buy_for_text]' value='<?php echo esc_attr($options['etwp_fsn_buy_for_text']); ?>'>
    <?php
}
function etwp_fsn_more_for_text_render() {
    $options = get_option('etwp_fsn_settings');
    ?>
    <input type='text' name='etwp_fsn_settings[etwp_fsn_more_for_text]' value='<?php echo esc_attr($options['etwp_fsn_more_for_text']); ?>'>
    <?php
}

// Callback for settings section
function etwp_fsn_settings_section_callback() { 
    echo __('Set the minimum and maximum amounts to display the free shipping notice, and customize the notice text.', 'easytoolswp');
}

// Function to display the settings page
function etwp_fsn_options_page() { 
    ?><div class="wrap">
    <form action='options.php' method='post'>
        <?php
        settings_fields('etwp_fsnSettings');
        do_settings_sections('etwp_fsnSettings');
        submit_button();
        ?>
    </form></div>
    <?php
}

// Functions to display custom messages in the cart or checkout
function etwp_fsn_free_shipping_cart_label() {
    $message = etwp_fsn_get_free_shipping_message();
    if (!empty($message)) {
        echo '<div class="woocommerce-message">' . wp_kses_post($message) . '</div>';
    }
}
function etwp_fsn_free_shipping_checkout_label() {
    $message = etwp_fsn_get_free_shipping_message();
    if (!empty($message)) {
        echo '<div class="woocommerce-message">' . wp_kses_post($message) . '</div>';
    }
}

// Function to generate the free shipping message
function etwp_fsn_get_free_shipping_message() {
    if (!function_exists('WC')) return ''; // WooCommerce is not active

    $options = get_option('etwp_fsn_settings');
    $min = $options['etwp_fsn_min_amount'] ?? 0;
    $max = $options['etwp_fsn_max_amount'] ?? PHP_INT_MAX;
    $threshold = $options['etwp_fsn_free_shipping_amount'] ?? 0;
    $freeText = $options['etwp_fsn_free_shipping_text'] ?? __('You now have free shipping!', 'easytoolswp');
    $prefix = $options['etwp_fsn_buy_for_text'] ?? __('Buy for', 'easytoolswp');
    $suffix = $options['etwp_fsn_more_for_text'] ?? __('more for free delivery!', 'easytoolswp');

    $current = WC()->cart->total;

    if ($current < $min || $current > $max) return '';
    if ($current >= $threshold) return esc_html($freeText);

    return sprintf('%s %s %s', esc_html($prefix), wc_price($threshold - $current), esc_html($suffix));
}

// Add shortcode
add_shortcode('etwp_free_shipping', 'etwp_fsn_get_free_shipping_message');
?>
